==> open-cluster-management-apps-model-5.12.4-sources.jar: io/fabric8/openclustermanagement/api/model/app/k8s/v1beta1/DescriptorBuilder.java <==
package io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class DescriptorBuilder extends io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.DescriptorFluentImpl<io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.DescriptorBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.Descriptor,io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.DescriptorBuilder>{
  public DescriptorBuilder() {
    this(false);
  }
  public DescriptorBuilder(java.lang.Boolean validationEnabled) {
    this(new Descriptor(), validationEnabled);
  }
  public DescriptorBuilder(io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.DescriptorFluent<?> fluent) {
    this(fluent, false);
  }
  public DescriptorBuilder(io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.DescriptorFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Descriptor(), validationEnabled);
  }
  public DescriptorBuilder(io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.DescriptorFluent<?> fluent,io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.Descriptor instance) {
    this(fluent, instance, false);
  }
  public DescriptorBuilder(io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.DescriptorFluent<?> fluent,io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.Descriptor instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDescription(instance.getDescription()); 
    fluent.withIcons(instance.getIcons()); 
    fluent.withKeywords(instance.getKeywords()); 
    fluent.withLinks(instance.getLinks()); 
    fluent.withMaintainers(instance.getMaintainers()); 
    fluent.withNotes(instance.getNotes()); 
    fluent.withOwners(instance.getOwners()); 
    fluent.withType(instance.getType()); 
    fluent.withVersion(instance.getVersion()); 
    this.validationEnabled = validationEnabled; 
  }
  public DescriptorBuilder(io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.Descriptor instance) {
    this(instance,false);
  }
  public DescriptorBuilder(io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.Descriptor instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withDescription(instance.getDescription()); 
    this.withIcons(instance.getIcons()); 
    this.withKeywords(instance.getKeywords()); 
    this.withLinks(instance.getLinks()); 
    this.withMaintainers(instance.getMaintainers()); 
    this.withNotes(instance.getNotes()); 
    this.withOwners(instance.getOwners()); 
    this.withType(instance.getType()); 
    this.withVersion(instance.getVersion()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.DescriptorFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.Descriptor build() {
    Descriptor buildable = new Descriptor(fluent.getDescription(),fluent.getIcons(),fluent.getKeywords(),fluent.getLinks(),fluent.getMaintainers(),fluent.getNotes(),fluent.getOwners(),fluent.getType(),fluent.getVersion());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DescriptorBuilder that = (DescriptorBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> open-cluster-management-apps-model-6.3.0-sources.jar: io/fabric8/openclustermanagement/api/model/app/k8s/v1beta1/DescriptorBuilder.java <==
package io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class DescriptorBuilder extends DescriptorFluentImpl<DescriptorBuilder> implements VisitableBuilder<Descriptor,DescriptorBuilder>{
  public DescriptorBuilder() {
    this(false);
  }
  public DescriptorBuilder(Boolean validationEnabled) {
    this(new Descriptor(), validationEnabled);
  }
  public DescriptorBuilder(DescriptorFluent<?> fluent) {
    this(fluent, false);
  }
  public DescriptorBuilder(DescriptorFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Descriptor(), validationEnabled);
  }
  public DescriptorBuilder(DescriptorFluent<?> fluent,Descriptor instance) {
    this(fluent, instance, false);
  }
  public DescriptorBuilder(DescriptorFluent<?> fluent,Descriptor instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDescription(instance.getDescription()); 
    fluent.withIcons(instance.getIcons()); 
    fluent.withKeywords(instance.getKeywords()); 
    fluent.withLinks(instance.getLinks()); 
    fluent.withMaintainers(instance.getMaintainers()); 
    fluent.withNotes(instance.getNotes()); 
    fluent.withOwners(instance.getOwners()); 
    fluent.withType(instance.getType()); 
    fluent.withVersion(instance.getVersion()); 
    this.validationEnabled = validationEnabled; 
  }
  public DescriptorBuilder(Descriptor instance) {
    this(instance,false);
  }
  public DescriptorBuilder(Descriptor instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withDescription(instance.getDescription()); 
    this.withIcons(instance.getIcons()); 
    this.withKeywords(instance.getKeywords()); 
    this.withLinks(instance.getLinks()); 
    this.withMaintainers(instance.getMaintainers()); 
    this.withNotes(instance.getNotes()); 
    this.withOwners(instance.getOwners()); 
    this.withType(instance.getType()); 
    this.withVersion(instance.getVersion()); 
    this.validationEnabled = validationEnabled; 
  }
  DescriptorFluent<?> fluent;
  Boolean validationEnabled;
  public Descriptor build() {
    Descriptor buildable = new Descriptor(fluent.getDescription(),fluent.getIcons(),fluent.getKeywords(),fluent.getLinks(),fluent.getMaintainers(),fluent.getNotes(),fluent.getOwners(),fluent.getType(),fluent.getVersion());
    return buildable;
  }
  
}
